@@ -29,6 +29,7 @@ class _StatsigErrorBoundary:
     ):
         self._options = statsig_options
         self._metadata = statsig_metadata
+        self._timeout = statsig_options.timeout
 
     def set_diagnostics(self, diagnostics: Diagnostics):
         self._diagnostics = diagnostics
@@ -57,6 +58,7 @@ class _StatsigErrorBoundary:
         except (StatsigValueError, StatsigNameError, StatsigRuntimeError) as e:
             raise e
         except Exception as e:
+            print(f"Exception in {tag}: {e}")
             if self._init_context is not None:
                 self._init_context.error = e
             self.log_exception(tag, e, extra)
@@ -120,6 +122,7 @@ class _StatsigErrorBoundary:
 
     def _post_exception(self, name, info, tag, extra):
         try:
+            timeout = self._timeout if self._timeout is not None else REQUEST_TIMEOUT
             requests.post(
                 self.endpoint,
                 json={
@@ -138,7 +141,7 @@ class _StatsigErrorBoundary:
                     "STATSIG-SDK-TYPE": self._metadata["sdkType"],
                     "STATSIG-SDK-VERSION": self._metadata["sdkVersion"],
                 },
-                timeout=REQUEST_TIMEOUT,
+                timeout=timeout,
             )
         except BaseException:
             # no-op, best effort
